@@ -259,9 +259,11 @@ status_icon_filter_new_channel (EmpathyFilter     *filter,
 
 	priv = GET_PRIV (icon);
 
-	empathy_debug (DEBUG_DOMAIN, "New text channel to be filtered");
-
 	account = mission_control_get_account_for_connection (priv->mc, tp_conn, NULL);
+
+	empathy_debug (DEBUG_DOMAIN, "New text channel to be filtered for contact %s",
+		       empathy_inspect_channel (account, tp_chan));
+
 	tp_chat = empathy_tp_chat_new (account, tp_chan);
 	g_object_set_data (G_OBJECT (tp_chat), "filter", filter);
 	g_object_unref (account);
@@ -387,7 +389,7 @@ status_icon_toggle_visibility (EmpathyStatusIcon *icon)
 
 	priv = GET_PRIV (icon);
 
-	visible = empathy_window_get_is_visible (GTK_WINDOW (priv->window));
+	visible = gtk_window_has_toplevel_focus (GTK_WINDOW (priv->window));
 
 	if (visible) {
 		empathy_window_iconify (priv->window, priv->icon);
